@@ -758,7 +758,7 @@ class Builder(Update):
         if not cmd_path:
             raise BuilderError(_("Failed to find the %s command") % cmd)
         with EmergeParser(self.chrootize(builder_path, CommandExecutor(
-                builder_path, cmd_path, params, logfile=logfile))) as emerge:
+                cmd_path, params, logfile=logfile))) as emerge:
             revdep = RevdepPercentBlock(emerge)
             self.addProgress()
             revdep.add_observer(self.setProgress)
