@@ -89,7 +89,7 @@ class ClBuilderProfileAction(Action):
               },
              {'name': 'eix_update',
               'message': __("Updating the eix cache for "
-                            "{cl_builder_repository_name}"),
+                            "{cl_builder_eix_repositories}"),
               'method': 'Builder.eixUpdate(cl_builder_repository_name)',
               },
              # save
